

#include <stdio.h>
#include <errno.h>
#include "tedApp.h"
#include "sioStdio.h"





int main(int argc, char** argv)
{
  BufferDocument * bd;
  SimpleInputStream * sis = 0;
  DocumentGeometry geo;
  AppDrawingData add;
  Display *display;
  DocumentProperties *dp;
  FILE *ps;
  int ok;


  if (argc == 2 && !strcmp(argv[1],"--copyright")) {

    fprintf (stderr,
	"RTF to PostScript converter, based on Ted by Mark de Does [http://www.nllgg.nl/Ted]\n"
	"Motif and X server dependencies removed. Fredrik Sjoholm <fredrik@sjoholm.com>\n"
	"Released under the GNU Public License\n");
    exit(0);
  }


  if (argc < 2) {
    fprintf (stderr, "Usage: rtf2ps <input.rtf> [output.ps]\n");
    exit(1);
  }

  sis = sioInStdioOpen (argv[1]);

  if (!sis) {
    fprintf (stderr, "%s: %s\n", argv[1], strerror(errno));
    exit(1);
  }


  if (argc > 2) {
    ps = fopen (argv[2], "w");
  } else {
    ps = stdout;
  }


  bd = docRtfReadFile(  sis );



  appInitDocumentGeometry (&geo);


  appInitDrawingData (&add);
  // No X display, but we patched the XFont functions so it's not required
  appSetDrawingEnvironment (&add, 1.0, 1.0, "/usr/local/afm", 0, 0);
  appCleanDrawingData (&add);

  dp = &(bd->bdProperties);
  tedLayoutItem( &(bd->bdItem), dp, &add, &add.addBackRect);
  

  ok = docPsPrintDocument (
			ps,
			"",			// document title
			"rtf2ps",		// application name
			&add,
			bd,
			1,			// pages per page
			0,			// 1: print horizontal
			-1,			// first page
			-1,			// last page
			&geo,
			0,			// LAYOUT_HEADER layoutHeader
			0			// LAYOUT_FOOTER layoutFooter
  );

  if (ok == 0) return 0;

  return 1;
}




